@@ -8,7 +8,10 @@
 #' @param S number of samples from the Markov chain
 #' @param burn number of initial scans of the Markov chain to be dropped
 #' @param seed a random seed
-#' @param ... additional arguments passed to \code{eigenmodel::eigenmodel_mcmc}
+#' @param repulse logical. Add a small repulsion force with wordcloud package to avoid node overlap?
+#' @param repulsion scalar for the repulsion force (if repulse=T). Larger values add more repulsion
+#' @param eigenmodelArgs additional arguments in list format passed to \code{eigenmodel::eigenmodel_mcmc}
+#' @param ... additional arguments passed to \code{qgraph}
 #'
 #' @details
 #'
@@ -21,16 +24,24 @@
 #' Jones, P. J., Mair, P., & McNally, R. J. (2017). Scaling networks for two-dimensional visualization: a tutorial. Retrieved from osf.io/eugsz
 #'
 #' @export
-EIGENnet <- function(qgraph_net, EIGENadj=NULL, S=1000, burn=200,  seed=1, ...) {
+EIGENnet <- function(qgraph_net, EIGENadj=NULL, S=1000, burn=200, seed=1,
+                     repulse=F, repulsion=1, eigenmodelArgs = list(), ...) {
   if(is.null(EIGENadj)){
     adj <- qgraph::getWmat(qgraph_net)
   } else {
     adj <- EIGENadj
   }
   diag(adj) <- NA
-  fitEM <- eigenmodel::eigenmodel_mcmc(Y = adj, R = 2, S = S, burn = burn, seed = seed,...)
+  eigenmodelArgs <- c(eigenmodelArgs, list(Y = adj, R = 2,S = S, burn = burn, seed = seed))
+  fitEM <- do.call(what=eigenmodel::eigenmodel_mcmc,args=eigenmodelArgs)
   EVD <- eigen(fitEM$ULU_postmean)
   evecs <- EVD$vec[, 1:2]
-  qgraph::qgraph(qgraph_net, layout=evecs)
+  if(!repulse){
+    qgraph::qgraph(qgraph_net, layout=evecs,...)
+  } else {
+    message("When repulsion is used, plot is not exact. Compare to unrepulsed graph before interpreting")
+    repulse <- repulseLayout(qgraph_net, layout=evecs, repulsion=repulsion*.5)
+    qgraph::qgraph(qgraph_net, layout=repulse,...)
+  }
   invisible(evecs)
 }
